@@ -15,7 +15,7 @@ module Rerun
 
     def rails?
       rails_sig_file = File.expand_path(".")+"/config/boot.rb"
-      File.exists? rails_sig_file
+      File.exist? rails_sig_file
     end
 
   end
