@@ -1,6 +1,8 @@
 here = File.expand_path(File.dirname(__FILE__))
 require 'tmpdir'
 require_relative('../lib/rerun/system')
+require 'timeout'
+
 class IncProcess
 
   include Rerun::System
@@ -57,7 +59,7 @@ class IncProcess
 
   def launch
     @rerun_pid = spawn(rerun_cmd)
-    timeout(10) { sleep 0.5 until File.exist?(@inc_output_file) }
+    Timeout::timeout(10) { sleep 0.5 until File.exist?(@inc_output_file) }
     sleep 3 # let rerun's watcher get going
     read
   end
